@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+# -*- coding: utf-8 -*-
 #
 # This file is part of Panucci.
 # Copyright (c) 2008-2011 The Panucci Project
@@ -15,7 +15,6 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with Panucci.  If not, see <http://www.gnu.org/licenses/>.
-#
 
 from __future__ import absolute_import
 
@@ -82,6 +81,40 @@ class panucciInterface(dbus.service.Object):
         self.__log.debug('playPause() called')
         if self.player is not None: self.player.play_pause_toggle()
 
+    @dbus.service.method('org.panucci.panucciInterface')
+    def playNext(self):
+        self.__log.debug('playNext() called')
+        if self.player is not None: self.player.play_next()
+
+    @dbus.service.method('org.panucci.panucciInterface')
+    def playPrev(self):
+        self.__log.debug('playPrev() called')
+        if self.player is not None: self.player.play_prev()
+
+    @dbus.service.method('org.panucci.panucciInterface')
+    def backShort(self):
+        self.__log.debug('backShort() called')
+        seek_amount = self.gui.config.getint("options", "seek_short")
+        if self.player is not None: self.player.do_seek(from_current=-seek_amount*10**9)
+
+    @dbus.service.method('org.panucci.panucciInterface')
+    def forwardShort(self):
+        self.__log.debug('forwardShort() called')
+        seek_amount = self.gui.config.getint("options", "seek_short")
+        if self.player is not None: self.player.do_seek(from_current=seek_amount*10**9)
+
+    @dbus.service.method('org.panucci.panucciInterface')
+    def backLong(self):
+        self.__log.debug('backLong() called')
+        seek_amount = self.gui.config.getint("options", "seek_long")
+        if self.player is not None: self.player.do_seek(from_current=-seek_amount*10**9)
+
+    @dbus.service.method('org.panucci.panucciInterface')
+    def forwardLong(self):
+        self.__log.debug('forwardLong() called')
+        seek_amount = self.gui.config.getint("options", "seek_long")
+        if self.player is not None: self.player.do_seek(from_current=seek_amount*10**9)
+
     @dbus.service.method('org.panucci.panucciInterface', in_signature='s')
     def play_file(self, filepath):
         self.__log.debug('play_file() called with: ' + filepath)
@@ -92,28 +125,29 @@ class panucciInterface(dbus.service.Object):
     @dbus.service.method('org.panucci.panucciInterface', in_signature='su')
     def playback_from(self, uri, seconds):
         """Playback an URI from a position (in seconds)
-
         This sets the current file to "uri" and tries
         to start playback from the position given by
         the "seconds" parameter.
         """
+
         self.__log.debug('%s playback_from %d' % (uri, seconds))
         if self.player is not None:
             self.show_main_window()
 
             new_file = (self.player.playlist.current_filepath != uri)
 
-            if self.gui is not None:
-                self.gui.set_progress_indicator(new_file)
+            # I've diabled this for now as I've no possibility to debug it. /xerxes2
+            #if self.gui is not None:
+            #    self.gui.set_progress_indicator(new_file)
 
             if new_file:
                 self.player.playlist.load(uri)
-
-            if self.player._is_playing:
-                self.player.do_seek(from_beginning=(10**9)*seconds)
-            else:
                 self.player.playlist.set_seek_to(seconds)
+                self.player.playlist.last()
+            elif not self.player._is_playing:
                 self.player.play()
+            #else:
+            #    self.player.do_seek(from_beginning=(10**9)*seconds)
 
     @dbus.service.method('org.panucci.panucciInterface', in_signature='s')
     def queue_file(self, filepath):
@@ -157,4 +191,3 @@ class panucciInterface(dbus.service.Object):
 
 interface = panucciInterface(
     dbus.service.BusName('org.panucci.panucciInterface', session_bus) )
-
