@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+# -*- coding: utf-8 -*-
 #
 # This file is part of Panucci.
 # Copyright (c) 2008-2011 The Panucci Project
@@ -15,16 +15,13 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with Panucci.  If not, see <http://www.gnu.org/licenses/>.
-#
 
 from __future__ import absolute_import
 
 import logging
 
-from panucci.playlist import Playlist
 from panucci.services import ForwardingObservableService
 from panucci.dbusinterface import interface
-from panucci.backends import gstreamer
 
 from panucci import util
 
@@ -36,10 +33,14 @@ class PanucciPlayer(ForwardingObservableService):
     """
     signals = [ "playing", "paused", "stopped", "eof" ]
 
-    def __init__(self, player):
+    def __init__(self, playlist):
         self.__log = logging.getLogger('panucci.player.PanucciPlayer')
         ForwardingObservableService.__init__(self, self.signals, self.__log)
-        self.__player = player
+        self.config = playlist.config
+        if self.config.get("options", "backend") == "gstreamer":
+            from panucci.backends.gstreamer import Player
+        self.__player = Player()
+
         self.__initialized = False
         self._start_position = 0
         self._is_playing = False
@@ -52,10 +53,10 @@ class PanucciPlayer(ForwardingObservableService):
         self.__player.register( "playing", self.on_playing )
         self.__player.register( "paused", self.on_stopped )
         self.__player.register( "stopped", self.on_stopped )
-        self.__player.register( "eof", self.on_eof )
+        self.__player.register( "eof", self.on_stopped )
         self.__player.register( "error", self.on_player_error )
 
-        self.playlist = Playlist()
+        self.playlist = playlist
         self.playlist.register( 'new-track-loaded', self.on_new_track )
         self.playlist.register( 'seek-requested', self.do_seek )
         self.playlist.register( 'stop-requested', self.on_stop_requested )
@@ -82,7 +83,7 @@ class PanucciPlayer(ForwardingObservableService):
             Returns: (bookmark lable string, position in nanoseconds)
         """
 
-        default_label, position = player.get_formatted_position()
+        default_label, position = self.get_formatted_position()
         label = default_label if label is None else label
         self.playlist.save_bookmark( label, position )
         self.__log.info('Added bookmark: %s - %d', label, position)
@@ -100,27 +101,15 @@ class PanucciPlayer(ForwardingObservableService):
         text = util.convert_ns(pos)
         return (text, pos)
 
-    def init(self, filepath=None):
-        """ Start playing the current file in the playlist or a custom file.
-            This should be called by the UI once it has initialized.
-
-            Params: filepath is an optional filepath to the first file that
-                    should be loaded/played
-            Returns: Nothing
-        """
-
-        if filepath is None or not self.playlist.load( filepath ):
-            self.playlist.load_last_played()
-        else:
-            self.play()
-
     def on_new_track(self):
         """ New track callback; stops the player and starts the new track. """
 
         if self.playlist.current_filepath is not None:
+            
             filepath = self.playlist.current_filepath
             if filepath.startswith('/'):
                 filepath = 'file://' + filepath
+            
             self.load_media(filepath)
 
             # This is just here to prevent the player from starting to play
@@ -169,9 +158,6 @@ class PanucciPlayer(ForwardingObservableService):
             interface.PlaybackStopped(self._start_position, pos_sec, dur_sec, self.current_file)
         self._is_playing = False
 
-    def on_eof(self, *args):
-        self.playlist.next()
-
     @property
     def current_file(self):
         return self.playlist.current_filepath
@@ -187,11 +173,3 @@ class PanucciPlayer(ForwardingObservableService):
 
     def on_player_error(self, msg):
         self.__log.error("Error: %s", msg)
-
-    def quit(self):
-        """ Called when the application exits """
-        self.on_stop_requested()
-        self.playlist.quit()
-
-# there should only ever be one panucciPlayer object
-player = PanucciPlayer(gstreamer.GStreamerPlayer())
