@@ -15,19 +15,11 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with Panucci.  If not, see <http://www.gnu.org/licenses/>.
-#
 
 from __future__ import absolute_import
 
 import os.path
-
-about_name = 'Panucci'
-about_text = _('Resuming audiobook and podcast player')
-about_authors = ['Thomas Perl', 'Nick (nikosapi)', 'Matthew Taylor', 'Jens Persson']
-about_website = 'http://gpodder.org/panucci/'
-about_bugtracker = 'http://bugs.maemo.org/enter_bug.cgi?product=Panucci'
-about_donate = 'http://gpodder.org/donate'
-about_copyright = 'Copyright (c) 2008-2011 The Panucci Project'
+from sys import argv
 
 def convert_ns(time_int):
     """Convert nanosecond values into strings
@@ -78,3 +70,22 @@ def pretty_filename(filename):
     filename, extension = os.path.splitext(filename)
     basename = os.path.basename(filename)
     return basename.replace('_', ' ')
+
+def find_data_file(filename):
+    bin_dir = os.path.dirname(argv[0])
+    locations = [
+            os.path.join(bin_dir, '..', 'share', 'panucci'),
+            os.path.join(bin_dir, '..', 'icons'),
+            os.path.join(bin_dir, '..', 'data'),
+            '/opt/panucci',
+    ]
+
+    for location in locations:
+        fn = os.path.abspath(os.path.join(location, filename))
+        if os.path.exists(fn):
+            return fn
+
+def write_config(config):
+    _file = open(os.path.expanduser("~/.config/panucci/panucci-noedit.conf"), "w")
+    config.write(_file)
+    _file.close()
